@@ -4,6 +4,7 @@ from .resources.address_picker import Addresses
 from .resources.checks import Checks
 from .resources.reports import Reports
 from .resources.live_photos import LivePhotos
+from .resources.live_videos import LiveVideos
 from .resources.webhooks import Webhooks
 from .resources.sdk_tokens import SdkToken
 from .regions import Region
@@ -18,3 +19,4 @@ class Api:
         self.sdk_token = SdkToken(api_token, base_url)
         self.webhook = Webhooks(api_token, base_url)
         self.live_photo = LivePhotos(api_token, base_url)
+        self.live_video = LiveVideos(api_token, base_url)
